use crate::error::Result;
use crate::models::snippet::{Snippet, SnippetBody};
use crate::models::TrackId;
use crate::Musixmatch;

impl Musixmatch {
    /// Get a lyrics snippet for a track specified by its ID.
    ///
    /// A lyrics snippet is a very short representation of a song lyrics.
    /// It’s usually twenty to a hundred characters long and it’s calculated
    /// extracting a sequence of words from the lyrics.
    ///
    /// # Parameters
    /// - `id`: [Track ID](crate::models::TrackId)
    ///
    /// # Reference
    /// <https://developer.musixmatch.com/documentation/api-reference/track-snippet-get>
    pub async fn track_snippet(&self, id: TrackId<'_>) -> Result<Snippet> {
        let mut url = self.new_url("track.snippet.get");
        {
            let mut url_query = url.query_pairs_mut();

            let id_param = id.to_param();
            url_query.append_pair(id_param.0, &id_param.1);
            url_query.finish();
        }

        let snippet_body = self.execute_get_request::<SnippetBody>(&url).await?;
        Ok(snippet_body.snippet)
    }
}
