use serde::{Deserialize, Serialize};

/// List of music genres
#[derive(Default, Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
#[non_exhaustive]
pub struct Genres {
    /// List of music genres
    pub music_genre_list: Vec<Genre>,
}

/// Genre: a music genre in the Musixmatch database
#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
#[non_exhaustive]
pub struct Genre {
    /// Music genre
    pub music_genre: GenreInner,
}

/// Genre: a music genre in the Musixmatch database
#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
#[non_exhaustive]
pub struct GenreInner {
    /// Unique Musixmatch Genre ID
    pub music_genre_id: u64,
    /// ID of supergenre
    pub music_genre_parent_id: u64,
    /// Genre name
    pub music_genre_name: String,
    /// Long genre name
    pub music_genre_name_extended: String,
    /// URL-safe genre name
    ///
    /// **Note:** Jazz / Bebop (ID: 1291) has this set to None for some reason.
    pub music_genre_vanity: Option<String>,
}
