use serde::{Deserialize, Serialize};
use time::OffsetDateTime;

#[derive(Debug, Deserialize)]
pub(crate) struct SnippetBody {
    pub snippet: Snippet,
}

/// Snippet of lyrics text in the Musixmatch database.
///
/// A lyrics snippet is a very short representation of a song lyrics.
/// It’s usually twenty to a hundred characters long and it’s calculated
/// extracting a sequence of words from the lyrics.
///
/// Example: "There's not a thing that I would change"
#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
pub struct Snippet {
    /// Unique Musixmatch Snippet ID
    pub snippet_id: u64,
    /// Snippet language code (e.g. "en")
    #[serde(default, deserialize_with = "crate::api_model::null_if_empty")]
    pub snippet_language: Option<String>,
    /// True if the track is instrumental
    #[serde(default, deserialize_with = "crate::api_model::bool_from_int")]
    pub instrumental: bool,
    /// Date and time when the snippet was last updated
    #[serde(with = "time::serde::rfc3339")]
    pub updated_time: OffsetDateTime,
    /// Snippet text
    pub snippet_body: String,
}
